@@ -1,12 +1,17 @@
 # frozen_string_literal: true
 
 require 'English'
+
+# fileutils is autoloaded by pathname,
+# but must be explicitly loaded here for inclusion in `$LOADED_FEATURES`.
+require 'fileutils'
+
 before_us = $LOADED_FEATURES.dup
 require 'rainbow'
 
-require 'set'
-require 'forwardable'
 require 'regexp_parser'
+require 'set'
+require 'stringio'
 require 'unicode/display_width'
 
 # we have to require RuboCop's version, before rubocop-ast's
@@ -14,21 +19,25 @@ require_relative 'rubocop/version'
 require 'rubocop-ast'
 
 require_relative 'rubocop/ast_aliases'
+require_relative 'rubocop/ext/comment'
+require_relative 'rubocop/ext/range'
 require_relative 'rubocop/ext/regexp_node'
 require_relative 'rubocop/ext/regexp_parser'
-require_relative 'rubocop/ext/range'
 
 require_relative 'rubocop/core_ext/string'
 require_relative 'rubocop/ext/processed_source'
 
-require_relative 'rubocop/path_util'
-require_relative 'rubocop/file_finder'
-require_relative 'rubocop/platform'
-require_relative 'rubocop/name_similarity'
-require_relative 'rubocop/string_interpreter'
 require_relative 'rubocop/error'
-require_relative 'rubocop/warning'
+require_relative 'rubocop/file_finder'
+require_relative 'rubocop/file_patterns'
+require_relative 'rubocop/name_similarity'
+require_relative 'rubocop/path_util'
+require_relative 'rubocop/platform'
+require_relative 'rubocop/string_interpreter'
 require_relative 'rubocop/util'
+require_relative 'rubocop/warning'
+
+# rubocop:disable Style/RequireOrder
 
 require_relative 'rubocop/cop/util'
 require_relative 'rubocop/cop/offense'
@@ -65,15 +74,18 @@ require_relative 'rubocop/cop/mixin/alignment'
 require_relative 'rubocop/cop/mixin/allowed_identifiers'
 require_relative 'rubocop/cop/mixin/allowed_methods'
 require_relative 'rubocop/cop/mixin/allowed_pattern'
+require_relative 'rubocop/cop/mixin/allowed_receivers'
 require_relative 'rubocop/cop/mixin/auto_corrector' # rubocop:todo Naming/InclusiveLanguage
 require_relative 'rubocop/cop/mixin/check_assignment'
 require_relative 'rubocop/cop/mixin/check_line_breakable'
+require_relative 'rubocop/cop/mixin/check_single_line_suitability'
 require_relative 'rubocop/cop/mixin/configurable_max'
 require_relative 'rubocop/cop/mixin/code_length' # relies on configurable_max
 require_relative 'rubocop/cop/mixin/configurable_enforced_style'
 require_relative 'rubocop/cop/mixin/configurable_formatting'
 require_relative 'rubocop/cop/mixin/configurable_naming'
 require_relative 'rubocop/cop/mixin/configurable_numbering'
+require_relative 'rubocop/cop/mixin/dig_help'
 require_relative 'rubocop/cop/mixin/documentation_comment'
 require_relative 'rubocop/cop/mixin/duplication'
 require_relative 'rubocop/cop/mixin/range_help'
@@ -81,12 +93,14 @@ require_relative 'rubocop/cop/mixin/annotation_comment' # relies on range
 require_relative 'rubocop/cop/mixin/empty_lines_around_body' # relies on range
 require_relative 'rubocop/cop/mixin/empty_parameter'
 require_relative 'rubocop/cop/mixin/end_keyword_alignment'
+require_relative 'rubocop/cop/mixin/endless_method_rewriter'
 require_relative 'rubocop/cop/mixin/enforce_superclass'
 require_relative 'rubocop/cop/mixin/first_element_line_break'
 require_relative 'rubocop/cop/mixin/frozen_string_literal'
 require_relative 'rubocop/cop/mixin/gem_declaration'
 require_relative 'rubocop/cop/mixin/gemspec_help'
 require_relative 'rubocop/cop/mixin/hash_alignment_styles'
+require_relative 'rubocop/cop/mixin/hash_subset'
 require_relative 'rubocop/cop/mixin/hash_transform_method'
 require_relative 'rubocop/cop/mixin/integer_node'
 require_relative 'rubocop/cop/mixin/interpolation'
@@ -98,6 +112,7 @@ require_relative 'rubocop/cop/mixin/hash_shorthand_syntax'
 require_relative 'rubocop/cop/mixin/method_complexity'
 require_relative 'rubocop/cop/mixin/method_preference'
 require_relative 'rubocop/cop/mixin/min_body_length'
+require_relative 'rubocop/cop/mixin/min_branches_count'
 require_relative 'rubocop/cop/mixin/multiline_element_indentation'
 require_relative 'rubocop/cop/mixin/multiline_element_line_breaks'
 require_relative 'rubocop/cop/mixin/multiline_expression_indentation'
@@ -155,14 +170,17 @@ require_relative 'rubocop/cop/correctors/string_literal_corrector'
 require_relative 'rubocop/cop/correctors/unused_arg_corrector'
 
 require_relative 'rubocop/cop/bundler/duplicated_gem'
+require_relative 'rubocop/cop/bundler/duplicated_group'
 require_relative 'rubocop/cop/bundler/gem_comment'
 require_relative 'rubocop/cop/bundler/gem_filename'
 require_relative 'rubocop/cop/bundler/gem_version'
 require_relative 'rubocop/cop/bundler/insecure_protocol_source'
 require_relative 'rubocop/cop/bundler/ordered_gems'
 
+require_relative 'rubocop/cop/gemspec/add_runtime_dependency'
 require_relative 'rubocop/cop/gemspec/dependency_version'
 require_relative 'rubocop/cop/gemspec/deprecated_attribute_assignment'
+require_relative 'rubocop/cop/gemspec/development_dependencies'
 require_relative 'rubocop/cop/gemspec/duplicated_assignment'
 require_relative 'rubocop/cop/gemspec/ordered_dependencies'
 require_relative 'rubocop/cop/gemspec/require_mfa'
@@ -275,6 +293,7 @@ require_relative 'rubocop/cop/lint/ambiguous_operator'
 require_relative 'rubocop/cop/lint/ambiguous_operator_precedence'
 require_relative 'rubocop/cop/lint/ambiguous_range'
 require_relative 'rubocop/cop/lint/ambiguous_regexp_literal'
+require_relative 'rubocop/cop/lint/array_literal_in_regexp'
 require_relative 'rubocop/cop/lint/assignment_in_condition'
 require_relative 'rubocop/cop/lint/big_decimal_new'
 require_relative 'rubocop/cop/lint/binary_operator_with_identical_operands'
@@ -282,7 +301,9 @@ require_relative 'rubocop/cop/lint/boolean_symbol'
 require_relative 'rubocop/cop/lint/circular_argument_reference'
 require_relative 'rubocop/cop/lint/constant_definition_in_block'
 require_relative 'rubocop/cop/lint/constant_overwritten_in_rescue'
+require_relative 'rubocop/cop/lint/constant_reassignment'
 require_relative 'rubocop/cop/lint/constant_resolution'
+require_relative 'rubocop/cop/lint/cop_directive_syntax'
 require_relative 'rubocop/cop/lint/debugger'
 require_relative 'rubocop/cop/lint/deprecated_class_methods'
 require_relative 'rubocop/cop/lint/deprecated_constants'
@@ -293,10 +314,12 @@ require_relative 'rubocop/cop/lint/duplicate_case_condition'
 require_relative 'rubocop/cop/lint/duplicate_elsif_condition'
 require_relative 'rubocop/cop/lint/duplicate_hash_key'
 require_relative 'rubocop/cop/lint/duplicate_magic_comment'
+require_relative 'rubocop/cop/lint/duplicate_match_pattern'
 require_relative 'rubocop/cop/lint/duplicate_methods'
 require_relative 'rubocop/cop/lint/duplicate_regexp_character_class_element'
 require_relative 'rubocop/cop/lint/duplicate_require'
 require_relative 'rubocop/cop/lint/duplicate_rescue_exception'
+require_relative 'rubocop/cop/lint/duplicate_set_element'
 require_relative 'rubocop/cop/lint/each_with_object_argument'
 require_relative 'rubocop/cop/lint/else_layout'
 require_relative 'rubocop/cop/lint/empty_block'
@@ -309,12 +332,14 @@ require_relative 'rubocop/cop/lint/empty_in_pattern'
 require_relative 'rubocop/cop/lint/empty_interpolation'
 require_relative 'rubocop/cop/lint/empty_when'
 require_relative 'rubocop/cop/lint/ensure_return'
+require_relative 'rubocop/cop/lint/shared_mutable_default'
 require_relative 'rubocop/cop/lint/erb_new_arguments'
 require_relative 'rubocop/cop/lint/flip_flop'
 require_relative 'rubocop/cop/lint/float_comparison'
 require_relative 'rubocop/cop/lint/float_out_of_range'
 require_relative 'rubocop/cop/lint/format_parameter_mismatch'
 require_relative 'rubocop/cop/lint/hash_compare_by_identity'
+require_relative 'rubocop/cop/lint/hash_new_with_keyword_arguments_as_default'
 require_relative 'rubocop/cop/lint/heredoc_method_call_position'
 require_relative 'rubocop/cop/lint/identity_comparison'
 require_relative 'rubocop/cop/lint/implicit_string_concatenation'
@@ -322,12 +347,15 @@ require_relative 'rubocop/cop/lint/incompatible_io_select_with_fiber_scheduler'
 require_relative 'rubocop/cop/lint/ineffective_access_modifier'
 require_relative 'rubocop/cop/lint/inherit_exception'
 require_relative 'rubocop/cop/lint/interpolation_check'
+require_relative 'rubocop/cop/lint/it_without_arguments_in_block'
 require_relative 'rubocop/cop/lint/lambda_without_literal_block'
 require_relative 'rubocop/cop/lint/literal_as_condition'
+require_relative 'rubocop/cop/lint/literal_assignment_in_condition'
 require_relative 'rubocop/cop/lint/literal_in_interpolation'
 require_relative 'rubocop/cop/lint/loop'
 require_relative 'rubocop/cop/lint/missing_cop_enable_directive'
 require_relative 'rubocop/cop/lint/missing_super'
+require_relative 'rubocop/cop/lint/mixed_case_range'
 require_relative 'rubocop/cop/lint/mixed_regexp_capture_types'
 require_relative 'rubocop/cop/lint/multiple_comparison'
 require_relative 'rubocop/cop/lint/nested_method_definition'
@@ -339,6 +367,7 @@ require_relative 'rubocop/cop/lint/non_deterministic_require_order'
 require_relative 'rubocop/cop/lint/non_local_exit_from_iterator'
 require_relative 'rubocop/cop/lint/number_conversion'
 require_relative 'rubocop/cop/lint/numbered_parameter_assignment'
+require_relative 'rubocop/cop/lint/numeric_operation_with_constant_result'
 require_relative 'rubocop/cop/lint/or_assignment_to_constant'
 require_relative 'rubocop/cop/lint/ordered_magic_comments'
 require_relative 'rubocop/cop/lint/out_of_range_regexp_ref'
@@ -350,10 +379,12 @@ require_relative 'rubocop/cop/lint/rand_one'
 require_relative 'rubocop/cop/lint/redundant_cop_disable_directive'
 require_relative 'rubocop/cop/lint/redundant_cop_enable_directive'
 require_relative 'rubocop/cop/lint/redundant_dir_glob_sort'
+require_relative 'rubocop/cop/lint/redundant_regexp_quantifiers'
 require_relative 'rubocop/cop/lint/redundant_require_statement'
 require_relative 'rubocop/cop/lint/redundant_safe_navigation'
 require_relative 'rubocop/cop/lint/redundant_splat_expansion'
 require_relative 'rubocop/cop/lint/redundant_string_coercion'
+require_relative 'rubocop/cop/lint/redundant_type_conversion'
 require_relative 'rubocop/cop/lint/redundant_with_index'
 require_relative 'rubocop/cop/lint/redundant_with_object'
 require_relative 'rubocop/cop/lint/refinement_import_methods'
@@ -375,6 +406,7 @@ require_relative 'rubocop/cop/lint/shadowed_exception'
 require_relative 'rubocop/cop/lint/shadowing_outer_local_variable'
 require_relative 'rubocop/cop/lint/struct_new_override'
 require_relative 'rubocop/cop/lint/suppressed_exception'
+require_relative 'rubocop/cop/lint/suppressed_exception_in_number_conversion'
 require_relative 'rubocop/cop/lint/symbol_conversion'
 require_relative 'rubocop/cop/lint/syntax'
 require_relative 'rubocop/cop/lint/to_enum_arguments'
@@ -383,6 +415,7 @@ require_relative 'rubocop/cop/lint/top_level_return_with_argument'
 require_relative 'rubocop/cop/lint/trailing_comma_in_attribute_declaration'
 require_relative 'rubocop/cop/lint/triple_quotes'
 require_relative 'rubocop/cop/lint/underscore_prefixed_variable_name'
+require_relative 'rubocop/cop/lint/unescaped_bracket_in_regexp'
 require_relative 'rubocop/cop/lint/unexpected_block_arity'
 require_relative 'rubocop/cop/lint/unified_integer'
 require_relative 'rubocop/cop/lint/unmodified_reduce_accumulator'
@@ -394,8 +427,12 @@ require_relative 'rubocop/cop/lint/uri_escape_unescape'
 require_relative 'rubocop/cop/lint/uri_regexp'
 require_relative 'rubocop/cop/lint/useless_access_modifier'
 require_relative 'rubocop/cop/lint/useless_assignment'
+require_relative 'rubocop/cop/lint/useless_constant_scoping'
+require_relative 'rubocop/cop/lint/useless_defined'
 require_relative 'rubocop/cop/lint/useless_else_without_rescue'
 require_relative 'rubocop/cop/lint/useless_method_definition'
+require_relative 'rubocop/cop/lint/useless_numeric_operation'
+require_relative 'rubocop/cop/lint/useless_rescue'
 require_relative 'rubocop/cop/lint/useless_ruby2_keywords'
 require_relative 'rubocop/cop/lint/useless_setter_call'
 require_relative 'rubocop/cop/lint/useless_times'
@@ -410,6 +447,7 @@ require_relative 'rubocop/cop/metrics/abc_size'
 require_relative 'rubocop/cop/metrics/block_length'
 require_relative 'rubocop/cop/metrics/block_nesting'
 require_relative 'rubocop/cop/metrics/class_length'
+require_relative 'rubocop/cop/metrics/collection_literal_length'
 require_relative 'rubocop/cop/metrics/method_length'
 require_relative 'rubocop/cop/metrics/module_length'
 require_relative 'rubocop/cop/metrics/parameter_lists'
@@ -437,9 +475,12 @@ require_relative 'rubocop/cop/naming/variable_number'
 require_relative 'rubocop/cop/style/access_modifier_declarations'
 require_relative 'rubocop/cop/style/accessor_grouping'
 require_relative 'rubocop/cop/style/alias'
+require_relative 'rubocop/cop/style/ambiguous_endless_method_definition'
 require_relative 'rubocop/cop/style/and_or'
 require_relative 'rubocop/cop/style/arguments_forwarding'
 require_relative 'rubocop/cop/style/array_coercion'
+require_relative 'rubocop/cop/style/array_first_last'
+require_relative 'rubocop/cop/style/array_intersect'
 require_relative 'rubocop/cop/style/array_join'
 require_relative 'rubocop/cop/style/ascii_comments'
 require_relative 'rubocop/cop/style/attr'
@@ -447,6 +488,7 @@ require_relative 'rubocop/cop/style/auto_resource_cleanup'
 require_relative 'rubocop/cop/style/bare_percent_literals'
 require_relative 'rubocop/cop/style/begin_block'
 require_relative 'rubocop/cop/style/bisected_attr_accessor'
+require_relative 'rubocop/cop/style/bitwise_predicate'
 require_relative 'rubocop/cop/style/block_comments'
 require_relative 'rubocop/cop/style/block_delimiters'
 require_relative 'rubocop/cop/style/case_equality'
@@ -462,16 +504,23 @@ require_relative 'rubocop/cop/style/collection_compact'
 require_relative 'rubocop/cop/style/collection_methods'
 require_relative 'rubocop/cop/style/colon_method_call'
 require_relative 'rubocop/cop/style/colon_method_definition'
+require_relative 'rubocop/cop/style/combinable_defined'
 require_relative 'rubocop/cop/style/combinable_loops'
 require_relative 'rubocop/cop/style/command_literal'
 require_relative 'rubocop/cop/style/comment_annotation'
 require_relative 'rubocop/cop/style/commented_keyword'
+require_relative 'rubocop/cop/style/comparable_between'
+require_relative 'rubocop/cop/style/comparable_clamp'
+require_relative 'rubocop/cop/style/concat_array_literals'
 require_relative 'rubocop/cop/style/conditional_assignment'
 require_relative 'rubocop/cop/style/constant_visibility'
 require_relative 'rubocop/cop/style/copyright'
+require_relative 'rubocop/cop/style/data_inheritance'
 require_relative 'rubocop/cop/style/date_time'
 require_relative 'rubocop/cop/style/def_with_parentheses'
+require_relative 'rubocop/cop/style/dig_chain'
 require_relative 'rubocop/cop/style/dir'
+require_relative 'rubocop/cop/style/dir_empty'
 require_relative 'rubocop/cop/style/disable_cops_within_source_code_directive'
 require_relative 'rubocop/cop/style/documentation_method'
 require_relative 'rubocop/cop/style/documentation'
@@ -493,11 +542,15 @@ require_relative 'rubocop/cop/style/end_block'
 require_relative 'rubocop/cop/style/env_home'
 require_relative 'rubocop/cop/style/eval_with_location'
 require_relative 'rubocop/cop/style/even_odd'
+require_relative 'rubocop/cop/style/exact_regexp_match'
 require_relative 'rubocop/cop/style/expand_path_arguments'
 require_relative 'rubocop/cop/style/explicit_block_argument'
 require_relative 'rubocop/cop/style/exponential_notation'
 require_relative 'rubocop/cop/style/fetch_env_var'
+require_relative 'rubocop/cop/style/file_empty'
+require_relative 'rubocop/cop/style/file_null'
 require_relative 'rubocop/cop/style/file_read'
+require_relative 'rubocop/cop/style/file_touch'
 require_relative 'rubocop/cop/style/file_write'
 require_relative 'rubocop/cop/style/float_division'
 require_relative 'rubocop/cop/style/for'
@@ -512,6 +565,7 @@ require_relative 'rubocop/cop/style/hash_conversion'
 require_relative 'rubocop/cop/style/hash_each_methods'
 require_relative 'rubocop/cop/style/hash_except'
 require_relative 'rubocop/cop/style/hash_like_case'
+require_relative 'rubocop/cop/style/hash_slice'
 require_relative 'rubocop/cop/style/hash_syntax'
 require_relative 'rubocop/cop/style/hash_transform_keys'
 require_relative 'rubocop/cop/style/hash_transform_values'
@@ -526,26 +580,46 @@ require_relative 'rubocop/cop/style/in_pattern_then'
 require_relative 'rubocop/cop/style/infinite_loop'
 require_relative 'rubocop/cop/style/inverse_methods'
 require_relative 'rubocop/cop/style/inline_comment'
+require_relative 'rubocop/cop/style/invertible_unless_condition'
 require_relative 'rubocop/cop/style/ip_addresses'
+require_relative 'rubocop/cop/style/it_assignment'
+require_relative 'rubocop/cop/style/keyword_arguments_merging'
 require_relative 'rubocop/cop/style/keyword_parameters_order'
 require_relative 'rubocop/cop/style/lambda'
 require_relative 'rubocop/cop/style/lambda_call'
 require_relative 'rubocop/cop/style/line_end_concatenation'
 require_relative 'rubocop/cop/style/magic_comment_format'
+require_relative 'rubocop/cop/style/map_into_array'
 require_relative 'rubocop/cop/style/map_to_hash'
+require_relative 'rubocop/cop/style/map_to_set'
 require_relative 'rubocop/cop/style/method_call_without_args_parentheses'
 require_relative 'rubocop/cop/style/method_call_with_args_parentheses'
+require_relative 'rubocop/cop/style/min_max_comparison'
 require_relative 'rubocop/cop/style/multiline_in_pattern_then'
 require_relative 'rubocop/cop/style/numbered_parameters'
 require_relative 'rubocop/cop/style/open_struct_use'
 require_relative 'rubocop/cop/style/operator_method_call'
+require_relative 'rubocop/cop/style/redundant_array_constructor'
 require_relative 'rubocop/cop/style/redundant_assignment'
+require_relative 'rubocop/cop/style/redundant_constant_base'
+require_relative 'rubocop/cop/style/redundant_current_directory_in_path'
+require_relative 'rubocop/cop/style/redundant_double_splat_hash_braces'
 require_relative 'rubocop/cop/style/redundant_each'
 require_relative 'rubocop/cop/style/redundant_fetch_block'
 require_relative 'rubocop/cop/style/redundant_file_extension_in_require'
+require_relative 'rubocop/cop/style/redundant_filter_chain'
+require_relative 'rubocop/cop/style/redundant_format'
+require_relative 'rubocop/cop/style/redundant_heredoc_delimiter_quotes'
 require_relative 'rubocop/cop/style/redundant_initialize'
+require_relative 'rubocop/cop/style/redundant_interpolation_unfreeze'
+require_relative 'rubocop/cop/style/redundant_line_continuation'
+require_relative 'rubocop/cop/style/redundant_regexp_argument'
+require_relative 'rubocop/cop/style/redundant_regexp_constructor'
 require_relative 'rubocop/cop/style/redundant_self_assignment'
 require_relative 'rubocop/cop/style/redundant_self_assignment_branch'
+require_relative 'rubocop/cop/style/require_order'
+require_relative 'rubocop/cop/style/safe_navigation_chain_length'
+require_relative 'rubocop/cop/style/single_line_do_end_block'
 require_relative 'rubocop/cop/style/sole_nested_conditional'
 require_relative 'rubocop/cop/style/static_class'
 require_relative 'rubocop/cop/style/map_compact_with_conditional_block'
@@ -620,12 +694,14 @@ require_relative 'rubocop/cop/style/regexp_literal'
 require_relative 'rubocop/cop/style/rescue_modifier'
 require_relative 'rubocop/cop/style/rescue_standard_error'
 require_relative 'rubocop/cop/style/return_nil'
+require_relative 'rubocop/cop/style/return_nil_in_predicate_method_definition'
 require_relative 'rubocop/cop/style/safe_navigation'
 require_relative 'rubocop/cop/style/sample'
 require_relative 'rubocop/cop/style/select_by_regexp'
 require_relative 'rubocop/cop/style/self_assignment'
 require_relative 'rubocop/cop/style/semicolon'
 require_relative 'rubocop/cop/style/send'
+require_relative 'rubocop/cop/style/send_with_literal_method_name'
 require_relative 'rubocop/cop/style/signal_exception'
 require_relative 'rubocop/cop/style/single_argument_dig'
 require_relative 'rubocop/cop/style/single_line_block_params'
@@ -642,6 +718,8 @@ require_relative 'rubocop/cop/style/string_literals_in_interpolation'
 require_relative 'rubocop/cop/style/string_methods'
 require_relative 'rubocop/cop/style/strip'
 require_relative 'rubocop/cop/style/struct_inheritance'
+require_relative 'rubocop/cop/style/super_arguments'
+require_relative 'rubocop/cop/style/super_with_args_parentheses'
 require_relative 'rubocop/cop/style/swap_values'
 require_relative 'rubocop/cop/style/symbol_array'
 require_relative 'rubocop/cop/style/symbol_literal'
@@ -666,7 +744,9 @@ require_relative 'rubocop/cop/style/when_then'
 require_relative 'rubocop/cop/style/while_until_do'
 require_relative 'rubocop/cop/style/while_until_modifier'
 require_relative 'rubocop/cop/style/word_array'
+require_relative 'rubocop/cop/style/yaml_file_read'
 require_relative 'rubocop/cop/style/yoda_condition'
+require_relative 'rubocop/cop/style/yoda_expression'
 require_relative 'rubocop/cop/style/zero_length_predicate'
 
 require_relative 'rubocop/cop/security/compound_hash'
@@ -698,6 +778,7 @@ require_relative 'rubocop/config_store'
 require_relative 'rubocop/config_validator'
 require_relative 'rubocop/feature_loader'
 require_relative 'rubocop/lockfile'
+require_relative 'rubocop/lsp'
 require_relative 'rubocop/target_finder'
 require_relative 'rubocop/directive_comment'
 require_relative 'rubocop/comment_config'
@@ -710,6 +791,7 @@ require_relative 'rubocop/cli/command/base'
 require_relative 'rubocop/cli/command/auto_generate_config'
 require_relative 'rubocop/cli/command/execute_runner'
 require_relative 'rubocop/cli/command/init_dotfile'
+require_relative 'rubocop/cli/command/lsp'
 require_relative 'rubocop/cli/command/show_cops'
 require_relative 'rubocop/cli/command/show_docs_url'
 require_relative 'rubocop/cli/command/suggest_extensions'
@@ -720,6 +802,8 @@ require_relative 'rubocop/remote_config'
 require_relative 'rubocop/target_ruby'
 require_relative 'rubocop/yaml_duplication_checker'
 
+# rubocop:enable Style/RequireOrder
+
 unless File.exist?("#{__dir__}/../rubocop.gemspec") # Check if we are a gem
   RuboCop::ResultCache.rubocop_required_features = $LOADED_FEATURES - before_us
 end
